@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package App::Cmd::Subdispatch;
-$App::Cmd::Subdispatch::VERSION = '0.324';
+$App::Cmd::Subdispatch::VERSION = '0.330';
 use App::Cmd;
 use App::Cmd::Command;
 BEGIN { our @ISA = qw(App::Cmd::Command App::Cmd) } 
@@ -50,7 +50,7 @@ sub prepare {
     if (@args) {
       return $self->_bad_command(undef, $opt, @sub_args);
     } else {
-      return $self->prepare_default_command($opt, @sub_args);
+      return $self->_prepare_default_command($opt, @sub_args);
     }
   }
 }
@@ -110,7 +110,7 @@ App::Cmd::Subdispatch - an App::Cmd::Command that is also an App::Cmd
 
 =head1 VERSION
 
-version 0.324
+version 0.330
 
 =head1 METHODS
 
@@ -148,7 +148,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo Signes.
+This software is copyright (c) 2015 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
